@@ -37,33 +37,35 @@
 
 #include "FileAllocationIterator.h"
 
+#include <memory>
+
 namespace aria2 {
 
 class BinaryStream;
 
-class AdaptiveFileAllocationIterator:public FileAllocationIterator
-{
+class AdaptiveFileAllocationIterator : public FileAllocationIterator {
 private:
-  SharedHandle<FileAllocationIterator> allocator_;
+  std::unique_ptr<FileAllocationIterator> allocator_;
 
   BinaryStream* stream_;
 
-  off_t offset_;
+  int64_t offset_;
+
+  int64_t totalLength_;
 
-  uint64_t totalLength_;
 public:
-  AdaptiveFileAllocationIterator
-  (BinaryStream* stream, off_t offset, uint64_t totalLength);
+  AdaptiveFileAllocationIterator(BinaryStream* stream, int64_t offset,
+                                 int64_t totalLength);
 
   virtual ~AdaptiveFileAllocationIterator();
 
-  virtual void allocateChunk();
-  
-  virtual bool finished();
+  virtual void allocateChunk() CXX11_OVERRIDE;
 
-  virtual off_t getCurrentLength();
+  virtual bool finished() CXX11_OVERRIDE;
 
-  virtual uint64_t getTotalLength();
+  virtual int64_t getCurrentLength() CXX11_OVERRIDE;
+
+  virtual int64_t getTotalLength() CXX11_OVERRIDE;
 };
 
 } // namespace aria2
