@@ -40,78 +40,74 @@
 namespace aria2 {
 
 class Piece;
-class BtPieceMessage;
 class DownloadContext;
-
-typedef SharedHandle<BtPieceMessage> BtPieceMessageHandle;
+class PeerStorage;
 
 class BtPieceMessage : public AbstractBtMessage {
 private:
   size_t index_;
-  uint32_t begin_;
-  uint32_t blockLength_;
-  unsigned char* block_;
-  unsigned char* rawData_;
-  SharedHandle<DownloadContext> downloadContext_;
+  int32_t begin_;
+  int32_t blockLength_;
+  const unsigned char* data_;
+  DownloadContext* downloadContext_;
+  PeerStorage* peerStorage_;
 
-  static size_t MESSAGE_HEADER_LENGTH;
+  bool checkPieceHash(const std::shared_ptr<Piece>& piece);
 
-  bool checkPieceHash(const SharedHandle<Piece>& piece);
+  void onNewPiece(const std::shared_ptr<Piece>& piece);
 
-  void onNewPiece(const SharedHandle<Piece>& piece);
+  void onWrongPiece(const std::shared_ptr<Piece>& piece);
 
-  void onWrongPiece(const SharedHandle<Piece>& piece);
+  void pushPieceData(int64_t offset, int32_t length) const;
 
-  void erasePieceOnDisk(const SharedHandle<Piece>& piece);
-
-  void pushPieceData(off_t offset, size_t length) const;
 public:
-  BtPieceMessage(size_t index = 0, uint32_t begin = 0, size_t blockLength = 0);
+  BtPieceMessage(size_t index = 0, int32_t begin = 0, int32_t blockLength = 0);
 
   virtual ~BtPieceMessage();
 
   static const uint8_t ID = 7;
 
-  static const std::string NAME;
+  static const char NAME[];
 
   size_t getIndex() const { return index_; }
 
   void setIndex(size_t index) { index_ = index; }
 
-  uint32_t getBegin() const { return begin_; }
+  int32_t getBegin() const { return begin_; }
 
-  void setBegin(uint32_t begin) { begin_ = begin; }
+  void setBegin(int32_t begin) { begin_ = begin; }
 
-  const unsigned char* getBlock() const { return block_; }
+  const unsigned char* getBlock() const { return data_ + 9; }
 
-  size_t getBlockLength() const { return blockLength_; }
+  int32_t getBlockLength() const { return blockLength_; }
 
-  // Stores raw message data. After this function call, this object
-  // has ownership of data. Caller must not be free or alter data.
-  // Member block is pointed to block starting position in data.
-  void setRawMessage(unsigned char* data);
+  // Sets message payload data. Caller must not change or free data
+  // before doReceivedAction().
+  void setMsgPayload(const unsigned char* data);
 
-  void setBlockLength(size_t blockLength) { blockLength_ = blockLength; }
+  void setBlockLength(int32_t blockLength) { blockLength_ = blockLength; }
 
-  void setDownloadContext(const SharedHandle<DownloadContext>& downloadContext);
+  void setDownloadContext(DownloadContext* downloadContext);
 
-  static BtPieceMessageHandle create
-  (const unsigned char* data, size_t dataLength);
+  void setPeerStorage(PeerStorage* peerStorage);
 
-  virtual void doReceivedAction();
+  static std::unique_ptr<BtPieceMessage> create(const unsigned char* data,
+                                                size_t dataLength);
 
-  unsigned char* createMessageHeader();
+  virtual void doReceivedAction() CXX11_OVERRIDE;
+
+  void createMessageHeader(unsigned char* msgHeader) const;
 
   size_t getMessageHeaderLength();
 
-  virtual void send();
+  virtual void send() CXX11_OVERRIDE;
 
-  virtual std::string toString() const;
+  virtual std::string toString() const CXX11_OVERRIDE;
 
-  virtual void onChokingEvent(const BtChokingEvent& event);
-  
-  virtual void onCancelSendingPieceEvent
-  (const BtCancelSendingPieceEvent& event);
+  virtual void onChokingEvent(const BtChokingEvent& event) CXX11_OVERRIDE;
+
+  virtual void onCancelSendingPieceEvent(const BtCancelSendingPieceEvent& event)
+      CXX11_OVERRIDE;
 };
 
 } // namespace aria2
