@@ -37,72 +37,72 @@
 #include "DownloadEngine.h"
 #include "RequestGroup.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "message.h"
 #include "prefs.h"
 #include "DownloadContext.h"
 #include "a2functional.h"
 #include "RecoverableException.h"
+#include "util.h"
+#include "fmt.h"
 
 namespace aria2 {
 
-CheckIntegrityCommand::CheckIntegrityCommand
-(int32_t cuid, RequestGroup* requestGroup, DownloadEngine* e,
- const SharedHandle<CheckIntegrityEntry>& entry):
-  RealtimeCommand(cuid, requestGroup, e),
-  _entry(entry)
-{}
+CheckIntegrityCommand::CheckIntegrityCommand(cuid_t cuid,
+                                             RequestGroup* requestGroup,
+                                             DownloadEngine* e,
+                                             CheckIntegrityEntry* entry)
+    : RealtimeCommand{cuid, requestGroup, e}, entry_{entry}
+{
+}
 
-CheckIntegrityCommand::~CheckIntegrityCommand() {}
+CheckIntegrityCommand::~CheckIntegrityCommand()
+{
+  getDownloadEngine()->getCheckIntegrityMan()->dropPickedEntry();
+}
 
 bool CheckIntegrityCommand::executeInternal()
 {
-  if(_requestGroup->isHaltRequested()) {
+  if (getRequestGroup()->isHaltRequested()) {
     return true;
   }
-  _entry->validateChunk();
-  if(_entry->finished()) {
-    _e->_checkIntegrityMan->dropPickedEntry();
+  entry_->validateChunk();
+  if (entry_->finished()) {
     // Enable control file saving here. See also
     // RequestGroup::processCheckIntegrityEntry() to know why this is
     // needed.
-    _requestGroup->enableSaveControlFile();
-    if(_requestGroup->downloadFinished()) {
-      logger->notice(MSG_VERIFICATION_SUCCESSFUL,
-                     _requestGroup->getDownloadContext()->getBasePath().c_str());
-      std::vector<Command*> commands;
-      try {
-        _entry->onDownloadFinished(commands, _e);
-      } catch(RecoverableException& e) {
-        std::for_each(commands.begin(), commands.end(), Deleter());
-        throw;
-      }
-      _e->addCommand(commands);
-    } else {
-      logger->error(MSG_VERIFICATION_FAILED,
-                    _requestGroup->getDownloadContext()->getBasePath().c_str());
-      std::vector<Command*> commands;
-      try {
-        _entry->onDownloadIncomplete(commands,_e);
-      } catch(RecoverableException& e) {
-        std::for_each(commands.begin(), commands.end(), Deleter());
-        throw;
-      }
-      _e->addCommand(commands);
+    getRequestGroup()->enableSaveControlFile();
+    if (getRequestGroup()->downloadFinished()) {
+      A2_LOG_NOTICE(
+          fmt(MSG_VERIFICATION_SUCCESSFUL,
+              getRequestGroup()->getDownloadContext()->getBasePath().c_str()));
+      std::vector<std::unique_ptr<Command>> commands;
+      entry_->onDownloadFinished(commands, getDownloadEngine());
+      getDownloadEngine()->addCommand(std::move(commands));
     }
-    _e->setNoWait(true);
+    else {
+      A2_LOG_ERROR(
+          fmt(MSG_VERIFICATION_FAILED,
+              getRequestGroup()->getDownloadContext()->getBasePath().c_str()));
+      std::vector<std::unique_ptr<Command>> commands;
+      entry_->onDownloadIncomplete(commands, getDownloadEngine());
+      getDownloadEngine()->addCommand(std::move(commands));
+    }
+    getDownloadEngine()->setNoWait(true);
     return true;
-  } else {
-    _e->commands.push_back(this);
+  }
+  else {
+    getDownloadEngine()->addCommand(std::unique_ptr<Command>(this));
     return false;
   }
 }
 
 bool CheckIntegrityCommand::handleException(Exception& e)
 {
-  _e->_checkIntegrityMan->dropPickedEntry();
-  logger->error(MSG_FILE_VALIDATION_FAILURE, e, cuid);
-  logger->error(MSG_DOWNLOAD_NOT_COMPLETE,
-                cuid, _requestGroup->getDownloadContext()->getBasePath().c_str());
+  A2_LOG_ERROR_EX(fmt(MSG_FILE_VALIDATION_FAILURE, getCuid()), e);
+  A2_LOG_ERROR(
+      fmt(MSG_DOWNLOAD_NOT_COMPLETE, getCuid(),
+          getRequestGroup()->getDownloadContext()->getBasePath().c_str()));
   return true;
 }
 
