@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DHT_ABSTRACT_MESSAGE_H_
-#define _D_DHT_ABSTRACT_MESSAGE_H_
+#ifndef D_DHT_ABSTRACT_MESSAGE_H
+#define D_DHT_ABSTRACT_MESSAGE_H
 
 #include "DHTMessage.h"
 #include "A2STR.h"
@@ -46,23 +46,22 @@ class DHTMessageDispatcher;
 class DHTMessageFactory;
 class DHTRoutingTable;
 
-class DHTAbstractMessage:public DHTMessage {
+class DHTAbstractMessage : public DHTMessage {
 private:
-  WeakHandle<DHTConnection> connection_;
+  DHTConnection* connection_;
 
-  WeakHandle<DHTMessageDispatcher> dispatcher_;
+  DHTMessageDispatcher* dispatcher_;
 
-  WeakHandle<DHTMessageFactory> factory_;
+  DHTMessageFactory* factory_;
+
+  DHTRoutingTable* routingTable_;
 
-  WeakHandle<DHTRoutingTable> routingTable_;
 public:
-  DHTAbstractMessage(const SharedHandle<DHTNode>& localNode,
-                     const SharedHandle<DHTNode>& remoteNode,
+  DHTAbstractMessage(const std::shared_ptr<DHTNode>& localNode,
+                     const std::shared_ptr<DHTNode>& remoteNode,
                      const std::string& transactionID = A2STR::NIL);
 
-  virtual ~DHTAbstractMessage();
-
-  virtual bool send();
+  virtual bool send() CXX11_OVERRIDE;
 
   virtual const std::string& getType() const = 0;
 
@@ -70,35 +69,23 @@ public:
 
   std::string getBencodedMessage();
 
-  const WeakHandle<DHTConnection>& getConnection() const
-  {
-    return connection_;
-  }
+  DHTConnection* getConnection() const { return connection_; }
 
-  void setConnection(const WeakHandle<DHTConnection>& connection);
+  void setConnection(DHTConnection* connection);
 
-  const WeakHandle<DHTMessageDispatcher>& getMessageDispatcher() const
-  {
-    return dispatcher_;
-  }
+  DHTMessageDispatcher* getMessageDispatcher() const { return dispatcher_; }
 
-  void setMessageDispatcher(const WeakHandle<DHTMessageDispatcher>& dispatcher);
-  
-  const WeakHandle<DHTMessageFactory>& getMessageFactory() const
-  {
-    return factory_;
-  }
+  void setMessageDispatcher(DHTMessageDispatcher* dispatcher);
 
-  void setMessageFactory(const WeakHandle<DHTMessageFactory>& factory);
+  DHTMessageFactory* getMessageFactory() const { return factory_; }
 
-  const WeakHandle<DHTRoutingTable>& getRoutingTable() const
-  {
-    return routingTable_;
-  }
+  void setMessageFactory(DHTMessageFactory* factory);
 
-  void setRoutingTable(const WeakHandle<DHTRoutingTable>& routingTable);
+  DHTRoutingTable* getRoutingTable() const { return routingTable_; }
+
+  void setRoutingTable(DHTRoutingTable* routingTable);
 };
 
 } // namespace aria2
 
-#endif // _D_DHT_ABSTRACT_MESSAGE_H_
+#endif // D_DHT_ABSTRACT_MESSAGE_H
