@@ -32,11 +32,13 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DHT_GET_PEERS_COMMAND_H_
-#define _D_DHT_GET_PEERS_COMMAND_H_
+#ifndef D_DHT_GET_PEERS_COMMAND_H
+#define D_DHT_GET_PEERS_COMMAND_H
 
 #include "Command.h"
-#include "SharedHandle.h"
+
+#include <memory>
+
 #include "TimerA2.h"
 
 namespace aria2 {
@@ -50,48 +52,43 @@ class RequestGroup;
 class BtRuntime;
 class PeerStorage;
 
-class DHTGetPeersCommand:public Command {
+class DHTGetPeersCommand : public Command {
 private:
-  static const time_t GET_PEER_INTERVAL = (15*60);
-
-  static const time_t GET_PEER_MIN_INTERVAL = (5*60);
-
-  static const size_t MAX_RETRIES = 10;
-
   RequestGroup* requestGroup_;
 
-  SharedHandle<BtRuntime> btRuntime_;
+  std::shared_ptr<BtRuntime> btRuntime_;
 
-  SharedHandle<PeerStorage> peerStorage_;
+  std::shared_ptr<PeerStorage> peerStorage_;
 
   DownloadEngine* e_;
 
-  SharedHandle<DHTTaskQueue> taskQueue_;
+  DHTTaskQueue* taskQueue_;
 
-  SharedHandle<DHTTaskFactory> taskFactory_;
+  DHTTaskFactory* taskFactory_;
 
-  SharedHandle<DHTTask> task_;
+  std::shared_ptr<DHTTask> task_;
 
-  size_t numRetry_;
+  int numRetry_;
 
   Timer lastGetPeerTime_;
+
 public:
   DHTGetPeersCommand(cuid_t cuid, RequestGroup* requestGroup,
                      DownloadEngine* e);
 
   virtual ~DHTGetPeersCommand();
 
-  virtual bool execute();
+  virtual bool execute() CXX11_OVERRIDE;
 
-  void setTaskQueue(const SharedHandle<DHTTaskQueue>& taskQueue);
+  void setTaskQueue(DHTTaskQueue* taskQueue);
 
-  void setTaskFactory(const SharedHandle<DHTTaskFactory>& taskFactory);
+  void setTaskFactory(DHTTaskFactory* taskFactory);
 
-  void setBtRuntime(const SharedHandle<BtRuntime>& btRuntime);
+  void setBtRuntime(const std::shared_ptr<BtRuntime>& btRuntime);
 
-  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage);
+  void setPeerStorage(const std::shared_ptr<PeerStorage>& peerStorage);
 };
 
 } // namespace aria2
 
-#endif // _D_DHT_GET_PEERS_COMMAND_H_
+#endif // D_DHT_GET_PEERS_COMMAND_H
