@@ -52,42 +52,38 @@
 
 namespace aria2 {
 
-DHTPeerAnnounceStorage::DHTPeerAnnounceStorage() {}
-
-DHTPeerAnnounceStorage::~DHTPeerAnnounceStorage() {}
-
-namespace {
-class InfoHashLess
+DHTPeerAnnounceStorage::DHTPeerAnnounceStorage()
+    : taskQueue_{nullptr}, taskFactory_{nullptr}
 {
-public:
-  bool operator()(const SharedHandle<DHTPeerAnnounceEntry>& lhs,
-                  const SharedHandle<DHTPeerAnnounceEntry>& rhs)
-  {
-    return memcmp(lhs->getInfoHash(), rhs->getInfoHash(), DHT_ID_LENGTH) < 0;
-  }
-};
-} // namespace
+}
 
-SharedHandle<DHTPeerAnnounceEntry>
+bool DHTPeerAnnounceStorage::InfoHashLess::
+operator()(const std::shared_ptr<DHTPeerAnnounceEntry>& lhs,
+           const std::shared_ptr<DHTPeerAnnounceEntry>& rhs) const
+{
+  return memcmp(lhs->getInfoHash(), rhs->getInfoHash(), DHT_ID_LENGTH) < 0;
+}
+
+std::shared_ptr<DHTPeerAnnounceEntry>
 DHTPeerAnnounceStorage::getPeerAnnounceEntry(const unsigned char* infoHash)
 {
-  SharedHandle<DHTPeerAnnounceEntry> entry(new DHTPeerAnnounceEntry(infoHash));
+  auto entry = std::make_shared<DHTPeerAnnounceEntry>(infoHash);
 
-  std::deque<SharedHandle<DHTPeerAnnounceEntry> >::iterator i = 
-    std::lower_bound(entries_.begin(), entries_.end(), entry, InfoHashLess());
+  auto i = entries_.lower_bound(entry);
 
-  if(i != entries_.end() &&
-     memcmp(infoHash, (*i)->getInfoHash(), DHT_ID_LENGTH) == 0) {
+  if (i != entries_.end() &&
+      memcmp(infoHash, (*i)->getInfoHash(), DHT_ID_LENGTH) == 0) {
     entry = *i;
-  } else {
+  }
+  else {
     entries_.insert(i, entry);
   }
   return entry;
 }
 
-void
-DHTPeerAnnounceStorage::addPeerAnnounce(const unsigned char* infoHash,
-                                        const std::string& ipaddr, uint16_t port)
+void DHTPeerAnnounceStorage::addPeerAnnounce(const unsigned char* infoHash,
+                                             const std::string& ipaddr,
+                                             uint16_t port)
 {
   A2_LOG_DEBUG(fmt("Adding %s:%u to peer announce list: infoHash=%s",
                    ipaddr.c_str(), port,
@@ -97,44 +93,39 @@ DHTPeerAnnounceStorage::addPeerAnnounce(const unsigned char* infoHash,
 
 bool DHTPeerAnnounceStorage::contains(const unsigned char* infoHash) const
 {
-  SharedHandle<DHTPeerAnnounceEntry> entry(new DHTPeerAnnounceEntry(infoHash));
-  return 
-    std::binary_search(entries_.begin(), entries_.end(), entry, InfoHashLess());
+  auto entry = std::make_shared<DHTPeerAnnounceEntry>(infoHash);
+  return std::binary_search(entries_.begin(), entries_.end(), entry,
+                            InfoHashLess());
 }
 
-void DHTPeerAnnounceStorage::getPeers(std::vector<SharedHandle<Peer> >& peers,
+void DHTPeerAnnounceStorage::getPeers(std::vector<std::shared_ptr<Peer>>& peers,
                                       const unsigned char* infoHash)
 {
-  SharedHandle<DHTPeerAnnounceEntry> entry(new DHTPeerAnnounceEntry(infoHash));
+  auto entry = std::make_shared<DHTPeerAnnounceEntry>(infoHash);
 
-  std::deque<SharedHandle<DHTPeerAnnounceEntry> >::iterator i = 
-    std::lower_bound(entries_.begin(), entries_.end(), entry, InfoHashLess());
-  if(i != entries_.end() &&
-     memcmp(infoHash, (*i)->getInfoHash(), DHT_ID_LENGTH) == 0 &&
-     !(*i)->empty()) {
+  auto i = entries_.find(entry);
+  if (i != entries_.end()) {
     (*i)->getPeers(peers);
   }
 }
 
-namespace {
-class RemoveStalePeerAddrEntry
-{
-public:
-  void operator()(const SharedHandle<DHTPeerAnnounceEntry>& e)
-  {
-    e->removeStalePeerAddrEntry(DHT_PEER_ANNOUNCE_PURGE_INTERVAL);
-  }
-};
-} // namespace
-
 void DHTPeerAnnounceStorage::handleTimeout()
 {
   A2_LOG_DEBUG(fmt("Now purge peer announces(%lu entries) which are timed out.",
                    static_cast<unsigned long>(entries_.size())));
-  std::for_each(entries_.begin(), entries_.end(), RemoveStalePeerAddrEntry());
-  entries_.erase(std::remove_if(entries_.begin(), entries_.end(),
-                                mem_fun_sh(&DHTPeerAnnounceEntry::empty)),
-                 entries_.end());
+  std::for_each(std::begin(entries_), std::end(entries_),
+                [](const std::shared_ptr<DHTPeerAnnounceEntry>& e) {
+                  e->removeStalePeerAddrEntry(DHT_PEER_ANNOUNCE_PURGE_INTERVAL);
+                });
+
+  for (auto i = std::begin(entries_); i != std::end(entries_);) {
+    if ((*i)->empty()) {
+      entries_.erase(i++);
+    }
+    else {
+      ++i;
+    }
+  }
   A2_LOG_DEBUG(fmt("Currently %lu peer announce entries",
                    static_cast<unsigned long>(entries_.size())));
 }
@@ -142,27 +133,25 @@ void DHTPeerAnnounceStorage::handleTimeout()
 void DHTPeerAnnounceStorage::announcePeer()
 {
   A2_LOG_DEBUG("Now announcing peer.");
-  for(std::deque<SharedHandle<DHTPeerAnnounceEntry> >::iterator i =
-        entries_.begin(), eoi = entries_.end(); i != eoi; ++i) {
-    if((*i)->getLastUpdated().
-       difference(global::wallclock()) >= DHT_PEER_ANNOUNCE_INTERVAL) {
-      (*i)->notifyUpdate();
-      SharedHandle<DHTTask> task =
-        taskFactory_->createPeerAnnounceTask((*i)->getInfoHash());
-      taskQueue_->addPeriodicTask2(task);
-      A2_LOG_DEBUG
-        (fmt("Added 1 peer announce: infoHash=%s",
-             util::toHex((*i)->getInfoHash(), DHT_ID_LENGTH).c_str()));
+  for (auto& e : entries_) {
+    if (e->getLastUpdated().difference(global::wallclock()) <
+        DHT_PEER_ANNOUNCE_INTERVAL) {
+      continue;
     }
+    e->notifyUpdate();
+    auto task = taskFactory_->createPeerAnnounceTask(e->getInfoHash());
+    taskQueue_->addPeriodicTask2(task);
+    A2_LOG_DEBUG(fmt("Added 1 peer announce: infoHash=%s",
+                     util::toHex(e->getInfoHash(), DHT_ID_LENGTH).c_str()));
   }
 }
 
-void DHTPeerAnnounceStorage::setTaskQueue(const SharedHandle<DHTTaskQueue>& taskQueue)
+void DHTPeerAnnounceStorage::setTaskQueue(DHTTaskQueue* taskQueue)
 {
   taskQueue_ = taskQueue;
 }
 
-void DHTPeerAnnounceStorage::setTaskFactory(const SharedHandle<DHTTaskFactory>& taskFactory)
+void DHTPeerAnnounceStorage::setTaskFactory(DHTTaskFactory* taskFactory)
 {
   taskFactory_ = taskFactory;
 }
