@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DIRECT_DISK_ADAPTOR_H_
-#define _D_DIRECT_DISK_ADAPTOR_H_
+#ifndef D_DIRECT_DISK_ADAPTOR_H
+#define D_DIRECT_DISK_ADAPTOR_H
 
 #include "AbstractSingleDiskAdaptor.h"
 
@@ -41,13 +41,11 @@ namespace aria2 {
 
 class DirectDiskAdaptor : public AbstractSingleDiskAdaptor {
 public:
-  virtual const std::string& getFilePath();
+  virtual const std::string& getFilePath() CXX11_OVERRIDE;
 
-  virtual size_t utime(const Time& actime, const Time& modtime);
+  virtual size_t utime(const Time& actime, const Time& modtime) CXX11_OVERRIDE;
 };
 
-typedef SharedHandle<DirectDiskAdaptor> DirectDiskAdaptorHandle;
-
 } // namespace aria2
 
-#endif // _D_DIRECT_DISK_ADAPTOR_H_
+#endif // D_DIRECT_DISK_ADAPTOR_H
