@@ -88,18 +88,7 @@ FileEntry::FileEntry()
 {
 }
 
-FileEntry::~FileEntry() {}
-
-FileEntry& FileEntry::operator=(const FileEntry& entry)
-{
-  if (this != &entry) {
-    path_ = entry.path_;
-    length_ = entry.length_;
-    offset_ = entry.offset_;
-    requested_ = entry.requested_;
-  }
-  return *this;
-}
+FileEntry::~FileEntry() = default;
 
 bool FileEntry::operator<(const FileEntry& fileEntry) const
 {
@@ -184,8 +173,9 @@ std::shared_ptr<Request> FileEntry::getRequestWithInFlightHosts(
       continue;
     }
 
-    return req;
+    break;
   }
+  return req;
 }
 
 std::shared_ptr<Request> FileEntry::getRequest(
