@@ -37,32 +37,41 @@
 #include "RequestGroupMan.h"
 #include "PieceStorage.h"
 #include "RequestGroup.h"
+#include "wallclock.h"
 
 namespace aria2 {
 
-HaveEraseCommand::HaveEraseCommand(cuid_t cuid, DownloadEngine* e, time_t interval)
-  :TimeBasedCommand(cuid, e, interval, true) {}
+HaveEraseCommand::HaveEraseCommand(cuid_t cuid, DownloadEngine* e,
+                                   std::chrono::seconds interval)
+    : TimeBasedCommand(cuid, e, std::move(interval), true)
+{
+}
 
-HaveEraseCommand::~HaveEraseCommand() {}
+HaveEraseCommand::~HaveEraseCommand() = default;
 
 void HaveEraseCommand::preProcess()
 {
-  if(getDownloadEngine()->getRequestGroupMan()->downloadFinished() ||
-     getDownloadEngine()->isHaltRequested()) {
+  if (getDownloadEngine()->getRequestGroupMan()->downloadFinished() ||
+      getDownloadEngine()->isHaltRequested()) {
     enableExit();
   }
 }
 
 void HaveEraseCommand::process()
 {
-  const RequestGroupList& groups =
-    getDownloadEngine()->getRequestGroupMan()->getRequestGroups();
-  for(RequestGroupList::SeqType::const_iterator i = groups.begin(),
-        eoi = groups.end(); i != eoi; ++i) {
-    const SharedHandle<PieceStorage>& ps = (*i).second->getPieceStorage();
-    if(ps) {
-      ps->removeAdvertisedPiece(5);
+  // we are making a copy of current wallclock.
+  auto expiry = global::wallclock();
+  expiry.sub(5_s);
+
+  const auto& groups =
+      getDownloadEngine()->getRequestGroupMan()->getRequestGroups();
+  for (auto& group : groups) {
+    const auto& ps = group->getPieceStorage();
+    if (!ps) {
+      continue;
     }
+
+    ps->removeAdvertisedPiece(expiry);
   }
 }
 
