@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HTTP_DOWNLOAD_COMMAND_H_
-#define _D_HTTP_DOWNLOAD_COMMAND_H_
+#ifndef D_HTTP_DOWNLOAD_COMMAND_H
+#define D_HTTP_DOWNLOAD_COMMAND_H
 
 #include "DownloadCommand.h"
 
@@ -44,23 +44,23 @@ class HttpConnection;
 
 class HttpDownloadCommand : public DownloadCommand {
 private:
-  SharedHandle<HttpResponse> httpResponse_;
-  SharedHandle<HttpConnection> httpConnection_;
+  std::unique_ptr<HttpResponse> httpResponse_;
+  std::shared_ptr<HttpConnection> httpConnection_;
+
 protected:
-  virtual bool prepareForNextSegment();
-  virtual off_t getRequestEndOffset() const;
+  virtual bool prepareForNextSegment() CXX11_OVERRIDE;
+  virtual int64_t getRequestEndOffset() const CXX11_OVERRIDE;
+
 public:
-  HttpDownloadCommand(cuid_t cuid,
-                      const SharedHandle<Request>& req,
-                      const SharedHandle<FileEntry>& fileEntry,
+  HttpDownloadCommand(cuid_t cuid, const std::shared_ptr<Request>& req,
+                      const std::shared_ptr<FileEntry>& fileEntry,
                       RequestGroup* requestGroup,
-                      const SharedHandle<HttpResponse>& httpResponse,
-                      const SharedHandle<HttpConnection>& httpConnection,
-                      DownloadEngine* e,
-                      const SharedHandle<SocketCore>& s);
+                      std::unique_ptr<HttpResponse> httpResponse,
+                      const std::shared_ptr<HttpConnection>& httpConnection,
+                      DownloadEngine* e, const std::shared_ptr<SocketCore>& s);
   virtual ~HttpDownloadCommand();
 };
 
 } // namespace aria2
 
-#endif // _D_HTTP_DOWNLOAD_COMMAND_H_
+#endif // D_HTTP_DOWNLOAD_COMMAND_H
