@@ -38,29 +38,28 @@
 #include "HttpConnection.h"
 #include "HttpRequest.h"
 #include "Segment.h"
-#include "Socket.h"
-#include "DownloadContext.h"
+#include "SocketCore.h"
+#include "SocketRecvBuffer.h"
 
 namespace aria2 {
 
-HttpProxyResponseCommand::HttpProxyResponseCommand
-(int cuid,
- const RequestHandle& req,
- const SharedHandle<FileEntry>& fileEntry,
- RequestGroup* requestGroup,
- const HttpConnectionHandle& httpConnection,
- DownloadEngine* e,
- const SocketHandle& s)
-  :AbstractProxyResponseCommand(cuid, req, fileEntry, requestGroup,
-                                httpConnection, e, s)
-{}
-
-HttpProxyResponseCommand::~HttpProxyResponseCommand() {}
-
-Command* HttpProxyResponseCommand::getNextCommand()
+HttpProxyResponseCommand::HttpProxyResponseCommand(
+    cuid_t cuid, const std::shared_ptr<Request>& req,
+    const std::shared_ptr<FileEntry>& fileEntry, RequestGroup* requestGroup,
+    const std::shared_ptr<HttpConnection>& httpConnection, DownloadEngine* e,
+    const std::shared_ptr<SocketCore>& s)
+    : AbstractProxyResponseCommand(cuid, req, fileEntry, requestGroup,
+                                   httpConnection, e, s)
 {
-  return new HttpRequestCommand(cuid, req, _fileEntry,
-                                _requestGroup, httpConnection, e, socket);
+}
+
+HttpProxyResponseCommand::~HttpProxyResponseCommand() = default;
+
+std::unique_ptr<Command> HttpProxyResponseCommand::getNextCommand()
+{
+  return make_unique<HttpRequestCommand>(
+      getCuid(), getRequest(), getFileEntry(), getRequestGroup(),
+      getHttpConnection(), getDownloadEngine(), getSocket());
 }
 
 } // namespace aria2
