@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_INITIATOR_MSE_HANDSHAKE_COMMAND_H_
-#define _D_INITIATOR_MSE_HANDSHAKE_COMMAND_H_
+#ifndef D_INITIATOR_MSE_HANDSHAKE_COMMAND_H
+#define D_INITIATOR_MSE_HANDSHAKE_COMMAND_H
 
 #include "PeerAbstractCommand.h"
 
@@ -57,40 +57,43 @@ public:
     INITIATOR_RECEIVE_PAD_D_LENGTH,
     INITIATOR_RECEIVE_PAD_D,
   };
+
 private:
   RequestGroup* requestGroup_;
 
-  SharedHandle<PeerStorage> peerStorage_;
+  std::shared_ptr<PeerStorage> peerStorage_;
 
-  SharedHandle<PieceStorage> pieceStorage_;
+  std::shared_ptr<PieceStorage> pieceStorage_;
 
-  SharedHandle<BtRuntime> btRuntime_;
+  std::shared_ptr<BtRuntime> btRuntime_;
 
   Seq sequence_;
-  MSEHandshake* mseHandshake_;
+  std::unique_ptr<MSEHandshake> mseHandshake_;
+
+  const std::shared_ptr<Option>& getOption() const;
+
+  void tryNewPeer();
 
-  const SharedHandle<Option>& getOption() const;
 protected:
-  virtual bool executeInternal();
-  virtual bool prepareForNextPeer(time_t wait);
-  virtual void onAbort();
-  virtual bool exitBeforeExecute();
+  virtual bool executeInternal() CXX11_OVERRIDE;
+  virtual bool prepareForNextPeer(time_t wait) CXX11_OVERRIDE;
+  virtual void onAbort() CXX11_OVERRIDE;
+  virtual bool exitBeforeExecute() CXX11_OVERRIDE;
+
 public:
-  InitiatorMSEHandshakeCommand
-  (cuid_t cuid,
-   RequestGroup* requestGroup,
-   const SharedHandle<Peer>& peer,
-   DownloadEngine* e,
-   const SharedHandle<BtRuntime>& btRuntime,
-   const SharedHandle<SocketCore>& s);
+  InitiatorMSEHandshakeCommand(cuid_t cuid, RequestGroup* requestGroup,
+                               const std::shared_ptr<Peer>& peer,
+                               DownloadEngine* e,
+                               const std::shared_ptr<BtRuntime>& btRuntime,
+                               const std::shared_ptr<SocketCore>& s);
 
   virtual ~InitiatorMSEHandshakeCommand();
 
-  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage);
+  void setPeerStorage(const std::shared_ptr<PeerStorage>& peerStorage);
 
-  void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage);
+  void setPieceStorage(const std::shared_ptr<PieceStorage>& pieceStorage);
 };
 
 } // namespace aria2
 
-#endif // _D_INITIATOR_MSE_HANDSHAKE_COMMAND_H_
+#endif // D_INITIATOR_MSE_HANDSHAKE_COMMAND_H
