@@ -34,6 +34,7 @@
 /* copyright --> */
 #include "MSEHandshake.h"
 
+#include <array>
 #include <cstring>
 #include <cassert>
 
@@ -42,7 +43,7 @@
 #include "LogFactory.h"
 #include "Logger.h"
 #include "BtHandshakeMessage.h"
-#include "Socket.h"
+#include "SocketCore.h"
 #include "a2netcompat.h"
 #include "DHKeyExchange.h"
 #include "ARC4Encryptor.h"
@@ -63,61 +64,56 @@ namespace {
 
 const size_t MAX_PAD_LENGTH = 512;
 const size_t CRYPTO_BITFIELD_LENGTH = 4;
-const unsigned char VC[] = { 0, 0, 0, 0, 0, 0, 0, 0 };
+constexpr auto VC = std::array<unsigned char, MSEHandshake::VC_LENGTH>{};
 
-const unsigned char* PRIME = reinterpret_cast<const unsigned char*>("FFFFFFFFFFFFFFFFC90FDAA22168C234C4C6628B80DC1CD129024E088A67CC74020BBEA63B139B22514A08798E3404DDEF9519B3CD3A431B302B0A6DF25F14374FE1356D6D51C245E485B576625E7EC6F44C42E9A63A36210000000000090563");
+const unsigned char* PRIME = reinterpret_cast<const unsigned char*>(
+    "FFFFFFFFFFFFFFFFC90FDAA22168C234C4C6628B80DC1CD129024E088A67CC74020BBEA63B"
+    "139B22514A08798E3404DDEF9519B3CD3A431B302B0A6DF25F14374FE1356D6D51C245E485"
+    "B576625E7EC6F44C42E9A63A36210000000000090563");
 const unsigned char* GENERATOR = reinterpret_cast<const unsigned char*>("2");
 
 } // namespace
 
-MSEHandshake::MSEHandshake
-(cuid_t cuid,
- const SocketHandle& socket,
- const Option* op)
-  : cuid_(cuid),
-    socket_(socket),
-    wantRead_(false),
-    option_(op),
-    rbufLength_(0),
-    socketBuffer_(socket),
-    negotiatedCryptoType_(CRYPTO_NONE),
-    dh_(0),
-    initiator_(true),
-    markerIndex_(0),
-    padLength_(0),
-    iaLength_(0),
-    ia_(0),
-    sha1_(MessageDigest::sha1())
-{}
-
-MSEHandshake::~MSEHandshake()
+MSEHandshake::MSEHandshake(cuid_t cuid,
+                           const std::shared_ptr<SocketCore>& socket,
+                           const Option* op)
+    : cuid_(cuid),
+      socket_(socket),
+      wantRead_(false),
+      option_(op),
+      rbufLength_(0),
+      socketBuffer_(socket),
+      negotiatedCryptoType_(CRYPTO_NONE),
+      initiator_(true),
+      markerIndex_(0),
+      padLength_(0),
+      iaLength_(0),
+      sha1_(MessageDigest::sha1())
 {
-  delete dh_;
-  delete [] ia_;
 }
 
+MSEHandshake::~MSEHandshake() = default;
+
 MSEHandshake::HANDSHAKE_TYPE MSEHandshake::identifyHandshakeType()
 {
-  if(rbufLength_ < 20) {
+  if (rbufLength_ < 20) {
     wantRead_ = true;
     return HANDSHAKE_NOT_YET;
   }
-  if(rbuf_[0] == BtHandshakeMessage::PSTR_LENGTH &&
-     memcmp(BtHandshakeMessage::BT_PSTR, rbuf_+1, 19) == 0) {
-    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - This is legacy BitTorrent handshake.",
-                     cuid_));
+  if (rbuf_[0] == BtHandshakeMessage::PSTR_LENGTH &&
+      memcmp(BtHandshakeMessage::BT_PSTR, rbuf_ + 1, 19) == 0) {
+    A2_LOG_DEBUG(
+        fmt("CUID#%" PRId64 " - This is legacy BitTorrent handshake.", cuid_));
     return HANDSHAKE_LEGACY;
-  } else {
-    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - This may be encrypted BitTorrent handshake.",
-                     cuid_));
-    return HANDSHAKE_ENCRYPTED;
   }
+  A2_LOG_DEBUG(fmt(
+      "CUID#%" PRId64 " - This may be encrypted BitTorrent handshake.", cuid_));
+  return HANDSHAKE_ENCRYPTED;
 }
 
 void MSEHandshake::initEncryptionFacility(bool initiator)
 {
-  delete dh_;
-  dh_ = new DHKeyExchange();
+  dh_ = make_unique<DHKeyExchange>();
   dh_->init(PRIME, PRIME_BITS, GENERATOR, 160);
   dh_->generatePublicKey();
   A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - DH initialized.", cuid_));
@@ -126,28 +122,27 @@ void MSEHandshake::initEncryptionFacility(bool initiator)
 
 void MSEHandshake::sendPublicKey()
 {
-  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - Sending public key.",
-                   cuid_));
-  unsigned char* buf = new unsigned char[KEY_LENGTH+MAX_PAD_LENGTH];
-  array_ptr<unsigned char> bufp(buf);
-  dh_->getPublicKey(buf, KEY_LENGTH);
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - Sending public key.", cuid_));
+  auto buf = std::vector<unsigned char>(KEY_LENGTH + MAX_PAD_LENGTH);
+  dh_->getPublicKey(buf.data(), KEY_LENGTH);
 
   size_t padLength =
-    SimpleRandomizer::getInstance()->getRandomNumber(MAX_PAD_LENGTH+1);
-  dh_->generateNonce(buf+KEY_LENGTH, padLength);
-  socketBuffer_.pushBytes(buf, KEY_LENGTH+padLength);
-  bufp.reset(0);
+      SimpleRandomizer::getInstance()->getRandomNumber(MAX_PAD_LENGTH + 1);
+  dh_->generateNonce(buf.data() + KEY_LENGTH, padLength);
+  buf.resize(KEY_LENGTH + padLength);
+
+  socketBuffer_.pushBytes(std::move(buf));
 }
 
 void MSEHandshake::read()
 {
-  if(rbufLength_ >= MAX_BUFFER_LENGTH) {
+  if (rbufLength_ >= MAX_BUFFER_LENGTH) {
     assert(!wantRead_);
     return;
   }
-  size_t len = MAX_BUFFER_LENGTH-rbufLength_;
-  socket_->readData(rbuf_+rbufLength_, len);
-  if(len == 0  && !socket_->wantRead() && !socket_->wantWrite()) {
+  size_t len = MAX_BUFFER_LENGTH - rbufLength_;
+  socket_->readData(rbuf_ + rbufLength_, len);
+  if (len == 0 && !socket_->wantRead() && !socket_->wantWrite()) {
     // TODO Should we set graceful in peer?
     throw DL_ABORT_EX(EX_EOF_FROM_PEER);
   }
@@ -164,13 +159,13 @@ bool MSEHandshake::send()
 void MSEHandshake::shiftBuffer(size_t offset)
 {
   assert(rbufLength_ >= offset);
-  memmove(rbuf_, rbuf_+offset, rbufLength_-offset);
+  memmove(rbuf_, rbuf_ + offset, rbufLength_ - offset);
   rbufLength_ -= offset;
 }
 
 bool MSEHandshake::receivePublicKey()
 {
-  if(rbufLength_ < KEY_LENGTH) {
+  if (rbufLength_ < KEY_LENGTH) {
     wantRead_ = true;
     return false;
   }
@@ -185,84 +180,84 @@ bool MSEHandshake::receivePublicKey()
 void MSEHandshake::initCipher(const unsigned char* infoHash)
 {
   memcpy(infoHash_, infoHash, INFO_HASH_LENGTH);
-  //Initialize cipher
-  unsigned char s[4+KEY_LENGTH+INFO_HASH_LENGTH];
-  memcpy(s, initiator_?"keyA":"keyB", 4);
-  memcpy(s+4, secret_, KEY_LENGTH);
-  memcpy(s+4+KEY_LENGTH, infoHash, INFO_HASH_LENGTH);
-  
+  // Initialize cipher
+  unsigned char s[4 + KEY_LENGTH + INFO_HASH_LENGTH];
+  memcpy(s, initiator_ ? "keyA" : "keyB", 4);
+  memcpy(s + 4, secret_, KEY_LENGTH);
+  memcpy(s + 4 + KEY_LENGTH, infoHash, INFO_HASH_LENGTH);
+
   unsigned char localCipherKey[20];
   sha1_->reset();
-  message_digest::digest(localCipherKey, sizeof(localCipherKey),
-                         sha1_, s, sizeof(s));
-  encryptor_.reset(new ARC4Encryptor());
+  message_digest::digest(localCipherKey, sizeof(localCipherKey), sha1_.get(), s,
+                         sizeof(s));
+  encryptor_ = make_unique<ARC4Encryptor>();
   encryptor_->init(localCipherKey, sizeof(localCipherKey));
 
   unsigned char peerCipherKey[20];
-  memcpy(s, initiator_?"keyB":"keyA", 4);
+  memcpy(s, initiator_ ? "keyB" : "keyA", 4);
   sha1_->reset();
-  message_digest::digest(peerCipherKey, sizeof(peerCipherKey),
-                         sha1_, s, sizeof(s));
-  decryptor_.reset(new ARC4Encryptor());
+  message_digest::digest(peerCipherKey, sizeof(peerCipherKey), sha1_.get(), s,
+                         sizeof(s));
+  decryptor_ = make_unique<ARC4Encryptor>();
   decryptor_->init(peerCipherKey, sizeof(peerCipherKey));
 
   // discard first 1024 bytes ARC4 output.
-  unsigned char garbage[1024];
-  encryptor_->encrypt(1024, garbage, garbage);
-  decryptor_->encrypt(1024, garbage, garbage);
+  std::array<unsigned char, 1_k> garbage;
+  encryptor_->encrypt(garbage.size(), garbage.data(), garbage.data());
+  decryptor_->encrypt(garbage.size(), garbage.data(), garbage.data());
 
-  if(initiator_) {
+  if (initiator_) {
     ARC4Encryptor enc;
     enc.init(peerCipherKey, sizeof(peerCipherKey));
     // discard first 1024 bytes ARC4 output.
-    enc.encrypt(1024, garbage, garbage);
-    enc.encrypt(VC_LENGTH, initiatorVCMarker_, VC);
+    enc.encrypt(garbage.size(), garbage.data(), garbage.data());
+    enc.encrypt(VC_LENGTH, initiatorVCMarker_, VC.data());
   }
 }
 
 // Given data is pushed to socketBuffer_ and data will be deleted by
 // socketBuffer_.
-void MSEHandshake::encryptAndSendData(unsigned char* data, size_t length)
+void MSEHandshake::encryptAndSendData(std::vector<unsigned char> data)
 {
-  encryptor_->encrypt(length, data, data);
-  socketBuffer_.pushBytes(data, length);
+  encryptor_->encrypt(data.size(), data.data(), data.data());
+  socketBuffer_.pushBytes(std::move(data));
 }
 
 void MSEHandshake::createReq1Hash(unsigned char* md) const
 {
   unsigned char buffer[100];
   memcpy(buffer, "req1", 4);
-  memcpy(buffer+4, secret_, KEY_LENGTH);
+  memcpy(buffer + 4, secret_, KEY_LENGTH);
   sha1_->reset();
-  message_digest::digest(md, 20, sha1_, buffer, 4+KEY_LENGTH);
+  message_digest::digest(md, 20, sha1_.get(), buffer, 4 + KEY_LENGTH);
 }
 
-void MSEHandshake::createReq23Hash(unsigned char* md, const unsigned char* infoHash) const
+void MSEHandshake::createReq23Hash(unsigned char* md,
+                                   const unsigned char* infoHash) const
 {
   unsigned char x[24];
   memcpy(x, "req2", 4);
-  memcpy(x+4, infoHash, INFO_HASH_LENGTH);
+  memcpy(x + 4, infoHash, INFO_HASH_LENGTH);
   unsigned char xh[20];
   sha1_->reset();
-  message_digest::digest(xh, sizeof(xh), sha1_, x, sizeof(x));
+  message_digest::digest(xh, sizeof(xh), sha1_.get(), x, sizeof(x));
 
-  unsigned char y[4+96];
+  unsigned char y[4 + 96];
   memcpy(y, "req3", 4);
-  memcpy(y+4, secret_, KEY_LENGTH);
+  memcpy(y + 4, secret_, KEY_LENGTH);
   unsigned char yh[20];
   sha1_->reset();
-  message_digest::digest(yh, sizeof(yh), sha1_, y, sizeof(y));
-  
-  for(size_t i = 0; i < 20; ++i) {
-    md[i] = xh[i]^yh[i];
+  message_digest::digest(yh, sizeof(yh), sha1_.get(), y, sizeof(y));
+
+  for (size_t i = 0; i < 20; ++i) {
+    md[i] = xh[i] ^ yh[i];
   }
 }
 
 uint16_t MSEHandshake::decodeLength16(const unsigned char* buffer)
 {
   uint16_t be;
-  decryptor_->encrypt(sizeof(be),
-                      reinterpret_cast<unsigned char*>(&be),
+  decryptor_->encrypt(sizeof(be), reinterpret_cast<unsigned char*>(&be),
                       buffer);
   return ntohs(be);
 }
@@ -271,54 +266,49 @@ void MSEHandshake::sendInitiatorStep2()
 {
   A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - Sending negotiation step2.", cuid_));
   // Assuming no exception
-  unsigned char* md = new unsigned char[20];
-  createReq1Hash(md);
-  socketBuffer_.pushBytes(md, 20);
+  auto md = std::vector<unsigned char>(20);
+  createReq1Hash(md.data());
+  socketBuffer_.pushBytes(std::move(md));
   // Assuming no exception
-  md = new unsigned char[20];
-  createReq23Hash(md, infoHash_);
-  socketBuffer_.pushBytes(md, 20);
+  md = std::vector<unsigned char>(20);
+  createReq23Hash(md.data(), infoHash_);
+  socketBuffer_.pushBytes(std::move(md));
   // buffer is filled in this order:
   //   VC(VC_LENGTH bytes),
   //   crypto_provide(CRYPTO_BITFIELD_LENGTH bytes),
   //   len(padC)(2 bytes),
   //   padC(len(padC) bytes <= MAX_PAD_LENGTH),
   //   len(IA)(2 bytes)
-  unsigned char* buffer = new unsigned char
-    [40+VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2+MAX_PAD_LENGTH+2];
-  array_ptr<unsigned char> bufp(buffer);
-  unsigned char* ptr = buffer;
+  auto buffer = std::vector<unsigned char>(VC_LENGTH + CRYPTO_BITFIELD_LENGTH +
+                                           2 + MAX_PAD_LENGTH + 2);
+  auto ptr = std::begin(buffer);
   // VC
-  memcpy(ptr, VC, sizeof(VC));
-  ptr += sizeof(VC);
+  ptr += VC_LENGTH;
   // crypto_provide
-  memset(ptr, 0, CRYPTO_BITFIELD_LENGTH);
-  if(option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
+  if (!option_->getAsBool(PREF_BT_FORCE_ENCRYPTION) &&
+      option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
     ptr[3] = CRYPTO_PLAIN_TEXT;
   }
   ptr[3] |= CRYPTO_ARC4;
   ptr += CRYPTO_BITFIELD_LENGTH;
   // len(padC)
   uint16_t padCLength =
-    SimpleRandomizer::getInstance()->getRandomNumber(MAX_PAD_LENGTH+1);
-  {
-    uint16_t padCLengthBE = htons(padCLength);
-    memcpy(ptr, &padCLengthBE, sizeof(padCLengthBE));
-  }
-  ptr += 2;
+      SimpleRandomizer::getInstance()->getRandomNumber(MAX_PAD_LENGTH + 1);
+  uint16_t padCLengthBE = htons(padCLength);
+  ptr = std::copy_n(reinterpret_cast<unsigned char*>(&padCLengthBE),
+                    sizeof(padCLengthBE), ptr);
   // padC
-  memset(ptr, 0, padCLength);
   ptr += padCLength;
   // len(IA)
   // currently, IA is zero-length.
   uint16_t iaLength = 0;
   {
     uint16_t iaLengthBE = htons(iaLength);
-    memcpy(ptr, &iaLengthBE, sizeof(iaLengthBE));
+    ptr = std::copy_n(reinterpret_cast<unsigned char*>(&iaLengthBE),
+                      sizeof(iaLengthBE), ptr);
   }
-  ptr += 2;
-  encryptAndSendData(buffer, ptr-buffer);
-  bufp.reset(0);
+  buffer.erase(ptr, std::end(buffer));
+  encryptAndSendData(std::move(buffer));
 }
 
 // This function reads exactly until the end of VC marker is reached.
@@ -327,66 +317,64 @@ bool MSEHandshake::findInitiatorVCMarker()
   // 616 is synchronization point of initiator
   // find vc
   unsigned char* ptr =
-    std::search(&rbuf_[0], &rbuf_[rbufLength_],
-                &initiatorVCMarker_[0], &initiatorVCMarker_[VC_LENGTH]);
-  if(ptr == &rbuf_[rbufLength_]) {
-    if(616-KEY_LENGTH <= rbufLength_) {
+      std::search(&rbuf_[0], &rbuf_[rbufLength_], &initiatorVCMarker_[0],
+                  &initiatorVCMarker_[VC_LENGTH]);
+  if (ptr == &rbuf_[rbufLength_]) {
+    if (616 - KEY_LENGTH <= rbufLength_) {
       throw DL_ABORT_EX("Failed to find VC marker.");
-    } else {
+    }
+    else {
       wantRead_ = true;
       return false;
     }
   }
-  markerIndex_ = ptr-rbuf_;
-  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - VC marker found at %lu",
-                   cuid_,
+  markerIndex_ = ptr - rbuf_;
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - VC marker found at %lu", cuid_,
                    static_cast<unsigned long>(markerIndex_)));
-  verifyVC(rbuf_+markerIndex_);
+  verifyVC(rbuf_ + markerIndex_);
   // shift rbuf
-  shiftBuffer(markerIndex_+VC_LENGTH);
+  shiftBuffer(markerIndex_ + VC_LENGTH);
   return true;
 }
 
 bool MSEHandshake::receiveInitiatorCryptoSelectAndPadDLength()
 {
-  if(CRYPTO_BITFIELD_LENGTH+2/* PadD length*/ > rbufLength_) {
+  if (CRYPTO_BITFIELD_LENGTH + 2 /* PadD length*/ > rbufLength_) {
     wantRead_ = true;
     return false;
   }
-  //verifyCryptoSelect
+  // verifyCryptoSelect
   unsigned char* rbufptr = rbuf_;
   decryptor_->encrypt(CRYPTO_BITFIELD_LENGTH, rbufptr, rbufptr);
-  if(rbufptr[3]&CRYPTO_PLAIN_TEXT &&
-     option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
-    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - peer prefers plaintext.",
-                     cuid_));
+  if ((rbufptr[3] & CRYPTO_PLAIN_TEXT) &&
+      !option_->getAsBool(PREF_BT_FORCE_ENCRYPTION) &&
+      option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
+    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - peer prefers plaintext.", cuid_));
     negotiatedCryptoType_ = CRYPTO_PLAIN_TEXT;
   }
-  if(rbufptr[3]&CRYPTO_ARC4) {
-    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - peer prefers ARC4",
-                     cuid_));
+  if (rbufptr[3] & CRYPTO_ARC4) {
+    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - peer prefers ARC4", cuid_));
     negotiatedCryptoType_ = CRYPTO_ARC4;
   }
-  if(negotiatedCryptoType_ == CRYPTO_NONE) {
-    throw DL_ABORT_EX
-      (fmt("CUID#%" PRId64 " - No supported crypto type selected.",
-           cuid_));
+  if (negotiatedCryptoType_ == CRYPTO_NONE) {
+    throw DL_ABORT_EX(
+        fmt("CUID#%" PRId64 " - No supported crypto type selected.", cuid_));
   }
   // padD length
   rbufptr += CRYPTO_BITFIELD_LENGTH;
   padLength_ = verifyPadLength(rbufptr, "PadD");
   // shift rbuf
-  shiftBuffer(CRYPTO_BITFIELD_LENGTH+2/* PadD length*/);
+  shiftBuffer(CRYPTO_BITFIELD_LENGTH + 2 /* PadD length*/);
   return true;
 }
 
 bool MSEHandshake::receivePad()
 {
-  if(padLength_ > rbufLength_) {
+  if (padLength_ > rbufLength_) {
     wantRead_ = true;
     return false;
   }
-  if(padLength_ == 0) {
+  if (padLength_ == 0) {
     return true;
   }
   decryptor_->encrypt(padLength_, rbuf_, rbuf_);
@@ -401,52 +389,50 @@ bool MSEHandshake::findReceiverHashMarker()
   // find hash('req1', S), S is secret_.
   unsigned char md[20];
   createReq1Hash(md);
-  unsigned char* ptr = std::search
-    (&rbuf_[0], &rbuf_[rbufLength_], &md[0], &md[sizeof(md)]);
-  if(ptr == &rbuf_[rbufLength_]) {
-    if(628-KEY_LENGTH <= rbufLength_) {
+  unsigned char* ptr =
+      std::search(&rbuf_[0], &rbuf_[rbufLength_], &md[0], &md[sizeof(md)]);
+  if (ptr == &rbuf_[rbufLength_]) {
+    if (628 - KEY_LENGTH <= rbufLength_) {
       throw DL_ABORT_EX("Failed to find hash marker.");
-    } else {
+    }
+    else {
       wantRead_ = true;
       return false;
     }
   }
-  markerIndex_ = ptr-rbuf_;
-  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - Hash marker found at %lu.",
-                   cuid_,
+  markerIndex_ = ptr - rbuf_;
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - Hash marker found at %lu.", cuid_,
                    static_cast<unsigned long>(markerIndex_)));
-  verifyReq1Hash(rbuf_+markerIndex_);
+  verifyReq1Hash(rbuf_ + markerIndex_);
   // shift rbuf_
-  shiftBuffer(markerIndex_+20);
+  shiftBuffer(markerIndex_ + 20);
   return true;
 }
 
-bool MSEHandshake::receiveReceiverHashAndPadCLength
-(const std::vector<SharedHandle<DownloadContext> >& downloadContexts)
+bool MSEHandshake::receiveReceiverHashAndPadCLength(
+    const std::vector<std::shared_ptr<DownloadContext>>& downloadContexts)
 {
-  if(20+VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2/*PadC length*/ > rbufLength_) {
+  if (20 + VC_LENGTH + CRYPTO_BITFIELD_LENGTH + 2 /*PadC length*/ >
+      rbufLength_) {
     wantRead_ = true;
     return false;
   }
   // resolve info hash
   // pointing to the position of HASH('req2', SKEY) xor HASH('req3', S)
   unsigned char* rbufptr = rbuf_;
-  SharedHandle<DownloadContext> downloadContext;
-  for(std::vector<SharedHandle<DownloadContext> >::const_iterator i =
-        downloadContexts.begin(), eoi = downloadContexts.end();
-      i != eoi; ++i) {
+  std::shared_ptr<DownloadContext> downloadContext;
+  for (auto& ctx : downloadContexts) {
     unsigned char md[20];
-    const unsigned char* infohash = bittorrent::getInfoHash(*i);
+    const auto infohash = bittorrent::getInfoHash(ctx);
     createReq23Hash(md, infohash);
-    if(memcmp(md, rbufptr, sizeof(md)) == 0) {
-      A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - info hash found: %s",
-                       cuid_,
+    if (memcmp(md, rbufptr, sizeof(md)) == 0) {
+      A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - info hash found: %s", cuid_,
                        util::toHex(infohash, INFO_HASH_LENGTH).c_str()));
-      downloadContext = *i;
+      downloadContext = ctx;
       break;
     }
   }
-  if(!downloadContext) {
+  if (!downloadContext) {
     throw DL_ABORT_EX("Unknown info hash.");
   }
   initCipher(bittorrent::getInfoHash(downloadContext));
@@ -458,37 +444,36 @@ bool MSEHandshake::receiveReceiverHashAndPadCLength
   decryptor_->encrypt(CRYPTO_BITFIELD_LENGTH, rbufptr, rbufptr);
   // TODO choose the crypto type based on the preference.
   // For now, choose ARC4.
-  if(rbufptr[3]&CRYPTO_PLAIN_TEXT &&
-     option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
-    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - peer provides plaintext.",
-                     cuid_));
+  if ((rbufptr[3] & CRYPTO_PLAIN_TEXT) &&
+      !option_->getAsBool(PREF_BT_FORCE_ENCRYPTION) &&
+      option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
+    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - peer provides plaintext.", cuid_));
     negotiatedCryptoType_ = CRYPTO_PLAIN_TEXT;
-  } else if(rbufptr[3]&CRYPTO_ARC4) {
-    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - peer provides ARC4.",
-                     cuid_));
+  }
+  else if (rbufptr[3] & CRYPTO_ARC4) {
+    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - peer provides ARC4.", cuid_));
     negotiatedCryptoType_ = CRYPTO_ARC4;
   }
-  if(negotiatedCryptoType_ == CRYPTO_NONE) {
-    throw DL_ABORT_EX
-      (fmt("CUID#%" PRId64 " - No supported crypto type provided.",
-           cuid_));
+  if (negotiatedCryptoType_ == CRYPTO_NONE) {
+    throw DL_ABORT_EX(
+        fmt("CUID#%" PRId64 " - No supported crypto type provided.", cuid_));
   }
   // decrypt PadC length
   rbufptr += CRYPTO_BITFIELD_LENGTH;
   padLength_ = verifyPadLength(rbufptr, "PadC");
   // shift rbuf_
-  shiftBuffer(20+VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2/*PadC length*/);
+  shiftBuffer(20 + VC_LENGTH + CRYPTO_BITFIELD_LENGTH + 2 /*PadC length*/);
   return true;
 }
 
 bool MSEHandshake::receiveReceiverIALength()
 {
-  if(2 > rbufLength_) {
+  if (2 > rbufLength_) {
     wantRead_ = true;
     return false;
   }
   iaLength_ = decodeLength16(rbuf_);
-  if(iaLength_ > BtHandshakeMessage::MESSAGE_LENGTH) {
+  if (iaLength_ > BtHandshakeMessage::MESSAGE_LENGTH) {
     throw DL_ABORT_EX(fmt("Too large IA length length: %u", iaLength_));
   }
   A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - len(IA)=%u.", cuid_, iaLength_));
@@ -499,16 +484,15 @@ bool MSEHandshake::receiveReceiverIALength()
 
 bool MSEHandshake::receiveReceiverIA()
 {
-  if(iaLength_ == 0) {
+  if (iaLength_ == 0) {
     return true;
   }
-  if(iaLength_ > rbufLength_) {
+  if (iaLength_ > rbufLength_) {
     wantRead_ = true;
     return false;
   }
-  delete [] ia_;
-  ia_ = new unsigned char[iaLength_];
-  decryptor_->encrypt(iaLength_, ia_, rbuf_);
+  ia_ = std::vector<unsigned char>(iaLength_);
+  decryptor_->encrypt(iaLength_, ia_.data(), rbuf_);
   A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - IA received.", cuid_));
   // shift rbuf_
   shiftBuffer(iaLength_);
@@ -522,40 +506,35 @@ void MSEHandshake::sendReceiverStep2()
   //   cryptoSelect(CRYPTO_BITFIELD_LENGTH bytes),
   //   len(padD)(2bytes),
   //   padD(len(padD)bytes <= MAX_PAD_LENGTH)
-  unsigned char* buffer = new unsigned char
-    [VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2+MAX_PAD_LENGTH];
-  array_ptr<unsigned char> bufp(buffer);
-  unsigned char* ptr = buffer;
+  auto buffer = std::vector<unsigned char>(VC_LENGTH + CRYPTO_BITFIELD_LENGTH +
+                                           2 + MAX_PAD_LENGTH);
+  auto ptr = std::begin(buffer);
   // VC
-  memcpy(ptr, VC, sizeof(VC));
-  ptr += sizeof(VC);
+  ptr += VC_LENGTH;
   // crypto_select
-  memset(ptr, 0, CRYPTO_BITFIELD_LENGTH);
   ptr[3] = negotiatedCryptoType_;
   ptr += CRYPTO_BITFIELD_LENGTH;
   // len(padD)
   uint16_t padDLength =
-    SimpleRandomizer::getInstance()->getRandomNumber(MAX_PAD_LENGTH+1);
+      SimpleRandomizer::getInstance()->getRandomNumber(MAX_PAD_LENGTH + 1);
   uint16_t padDLengthBE = htons(padDLength);
-  memcpy(ptr, &padDLengthBE, sizeof(padDLengthBE));
-  ptr += sizeof(padDLengthBE);
+  ptr = std::copy_n(reinterpret_cast<unsigned char*>(&padDLengthBE),
+                    sizeof(padDLengthBE), ptr);
   // padD, all zeroed
-  memset(ptr, 0, padDLength);
   ptr += padDLength;
-  encryptAndSendData(buffer, ptr-buffer);
-  bufp.reset(0);
+  buffer.erase(ptr, std::end(buffer));
+  encryptAndSendData(std::move(buffer));
 }
 
-uint16_t MSEHandshake::verifyPadLength(const unsigned char* padlenbuf, const char* padName)
+uint16_t MSEHandshake::verifyPadLength(const unsigned char* padlenbuf,
+                                       const char* padName)
 {
-  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - Verifying Pad length for %s",
-                   cuid_, padName));
+  A2_LOG_DEBUG(
+      fmt("CUID#%" PRId64 " - Verifying Pad length for %s", cuid_, padName));
   uint16_t padLength = decodeLength16(padlenbuf);
-  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - len(%s)=%u",
-                   cuid_, padName, padLength));
-  if(padLength > 512) {
-    throw DL_ABORT_EX
-      (fmt("Too large %s length: %u", padName, padLength));
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - len(%s)=%u", cuid_, padName, padLength));
+  if (padLength > 512) {
+    throw DL_ABORT_EX(fmt("Too large %s length: %u", padName, padLength));
   }
   return padLength;
 }
@@ -564,9 +543,9 @@ void MSEHandshake::verifyVC(unsigned char* vcbuf)
 {
   A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - Verifying VC.", cuid_));
   decryptor_->encrypt(VC_LENGTH, vcbuf, vcbuf);
-  if(memcmp(VC, vcbuf, VC_LENGTH) != 0) {
-    throw DL_ABORT_EX
-      (fmt("Invalid VC: %s", util::toHex(vcbuf, VC_LENGTH).c_str()));
+  if (!std::equal(std::begin(VC), std::end(VC), vcbuf)) {
+    throw DL_ABORT_EX(
+        fmt("Invalid VC: %s", util::toHex(vcbuf, VC_LENGTH).c_str()));
   }
 }
 
@@ -575,7 +554,7 @@ void MSEHandshake::verifyReq1Hash(const unsigned char* req1buf)
   A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - Verifying req hash.", cuid_));
   unsigned char md[20];
   createReq1Hash(md);
-  if(memcmp(md, req1buf, sizeof(md)) != 0) {
+  if (memcmp(md, req1buf, sizeof(md)) != 0) {
     throw DL_ABORT_EX("Invalid req1 hash found.");
   }
 }
@@ -585,4 +564,14 @@ bool MSEHandshake::getWantWrite() const
   return !socketBuffer_.sendBufferIsEmpty();
 }
 
+std::unique_ptr<ARC4Encryptor> MSEHandshake::popEncryptor()
+{
+  return std::move(encryptor_);
+}
+
+std::unique_ptr<ARC4Encryptor> MSEHandshake::popDecryptor()
+{
+  return std::move(decryptor_);
+}
+
 } // namespace aria2
