@@ -32,27 +32,22 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_METALINK_POST_DOWNLOAD_HANDLER_H_
-#define _D_METALINK_POST_DOWNLOAD_HANDLER_H_
+#ifndef D_METALINK_POST_DOWNLOAD_HANDLER_H
+#define D_METALINK_POST_DOWNLOAD_HANDLER_H
 
 #include "PostDownloadHandler.h"
 
 namespace aria2 {
 
-class MetalinkPostDownloadHandler:public PostDownloadHandler
-{
+class MetalinkPostDownloadHandler : public PostDownloadHandler {
 public:
   MetalinkPostDownloadHandler();
 
-  virtual ~MetalinkPostDownloadHandler();
-
   virtual void
-  getNextRequestGroups(std::deque<SharedHandle<RequestGroup> >& groups,
-                       RequestGroup* requestGroup);
+  getNextRequestGroups(std::vector<std::shared_ptr<RequestGroup>>& groups,
+                       RequestGroup* requestGroup) const CXX11_OVERRIDE;
 };
 
-typedef SharedHandle<MetalinkPostDownloadHandler> MetalinkPostDownloadHandlerHandle;
-
 } // namespace aria2
 
-#endif // _D_METALINK_POST_DOWNLOAD_HANDLER_H_
+#endif // D_METALINK_POST_DOWNLOAD_HANDLER_H
