@@ -32,39 +32,43 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_METALINKER_H_
-#define _D_METALINKER_H_
+#ifndef D_METALINKER_H
+#define D_METALINKER_H
 
 #include "common.h"
-#include "SharedHandle.h"
+
 #include <string>
-#include <deque>
+#include <vector>
+#include <memory>
 
 namespace aria2 {
 
 class MetalinkEntry;
 
 class Metalinker {
-public:
-  std::deque<SharedHandle<MetalinkEntry> > entries;
+private:
+  std::vector<std::unique_ptr<MetalinkEntry>> entries_;
+
 public:
   Metalinker();
   ~Metalinker();
 
-  Metalinker& operator=(const Metalinker& metalinker) {
-    if(this != &metalinker) {
-      this->entries = metalinker.entries;
-    }
-    return *this;
+  // Don't allow copying
+  Metalinker(const Metalinker&) = delete;
+  Metalinker& operator=(const Metalinker&) = delete;
+
+  std::vector<std::unique_ptr<MetalinkEntry>>
+  queryEntry(const std::string& version, const std::string& language,
+             const std::string& os);
+
+  const std::vector<std::unique_ptr<MetalinkEntry>>& getEntries() const
+  {
+    return entries_;
   }
 
-  void queryEntry
-  (std::deque<SharedHandle<MetalinkEntry> >& queryResult,
-   const std::string& version,
-   const std::string& language,
-   const std::string& os) const;
+  void addEntry(std::unique_ptr<MetalinkEntry> entry);
 };
 
 } // namespace aria2
 
-#endif // _D_METALINKER_H_
+#endif // D_METALINKER_H
