@@ -35,57 +35,65 @@
 #include "Platform.h"
 
 #include <stdlib.h> /* _fmode */
-#include <fcntl.h> /*  _O_BINARY */
+#include <fcntl.h>  /*  _O_BINARY */
 
 #include <locale.h> // For setlocale, LC_*
 
 #include <iostream>
 
-#ifdef HAVE_WINSOCK2_H
-
-#ifndef _WIN32_WINNT
-# define _WIN32_WINNT 0x501u
-#endif // _WIN32_WINNT
-#include <winsock2.h>
-#undef ERROR
-#ifdef HAVE_WS2TCPIP_H
-# include <ws2tcpip.h>
-#endif // HAVE_WS2TCPIP_H
-
-#endif // HAVE_WINSOCK2_H
-
 #ifdef HAVE_OPENSSL
-# include <openssl/err.h>
-# include <openssl/ssl.h>
+#  include <openssl/err.h>
+#  include <openssl/ssl.h>
+#  include "libssl_compat.h"
 #endif // HAVE_OPENSSL
 #ifdef HAVE_LIBGCRYPT
-# include <gcrypt.h>
+#  include <gcrypt.h>
 #endif // HAVE_LIBGCRYPT
 #ifdef HAVE_LIBGNUTLS
-# include <gnutls/gnutls.h>
+#  include <gnutls/gnutls.h>
 #endif // HAVE_LIBGNUTLS
 
 #ifdef ENABLE_ASYNC_DNS
-# include <ares.h>
+#  include <ares.h>
 #endif // ENABLE_ASYNC_DNS
 
+#ifdef HAVE_LIBSSH2
+#  include <libssh2.h>
+#endif // HAVE_LIBSSH2
+
+#include "a2netcompat.h"
 #include "DlAbortEx.h"
 #include "message.h"
 #include "fmt.h"
+#include "console.h"
+#include "OptionParser.h"
+#include "prefs.h"
+#ifdef HAVE_LIBGMP
+#  include "a2gmp.h"
+#endif // HAVE_LIBGMP
+#include "LogFactory.h"
+#include "util.h"
 
 namespace aria2 {
 
+#ifdef HAVE_LIBGNUTLS
+namespace {
+void gnutls_log_callback(int level, const char* str)
+{
+  using namespace aria2;
+  // GnuTLS adds a newline. Drop it.
+  std::string msg(str);
+  msg.resize(msg.size() - 1);
+  A2_LOG_DEBUG(fmt("GnuTLS: <%d> %s", level, msg.c_str()));
+}
+} // namespace
+#endif // HAVE_LIBGNUTLS
+
 bool Platform::initialized_ = false;
 
-Platform::Platform()
-{
-  setUp();
-}
+Platform::Platform() { setUp(); }
 
-Platform::~Platform()
-{
-  tearDown();
-}
+Platform::~Platform() { tearDown(); }
 
 bool Platform::setUp()
 {
@@ -93,21 +101,27 @@ bool Platform::setUp()
     return false;
   }
   initialized_ = true;
-
+#ifdef HAVE_LIBGMP
+  global::initGmp();
+#endif // HAVE_LIBGMP
 #ifdef ENABLE_NLS
-  setlocale (LC_CTYPE, "");
-  setlocale (LC_MESSAGES, "");
-  bindtextdomain (PACKAGE, LOCALEDIR);
-  textdomain (PACKAGE);
+  setlocale(LC_CTYPE, "");
+  setlocale(LC_MESSAGES, "");
+  bindtextdomain(PACKAGE, LOCALEDIR);
+  textdomain(PACKAGE);
 #endif // ENABLE_NLS
 
 #ifdef HAVE_OPENSSL
+#  if !OPENSSL_101_API
   // for SSL initialization
   SSL_load_error_strings();
   SSL_library_init();
-#endif // HAVE_OPENSSL
+  // Need this to "decrypt" p12 files.
+  OpenSSL_add_all_algorithms();
+#  endif // !OPENSSL_101_API
+#endif   // HAVE_OPENSSL
 #ifdef HAVE_LIBGCRYPT
-  if(!gcry_check_version(GCRYPT_VERSION)) {
+  if (!gcry_check_version("1.2.4")) {
     throw DL_ABORT_EX("gcry_check_version() failed.");
   }
   gcry_control(GCRYCTL_DISABLE_SECMEM, 0);
@@ -116,22 +130,33 @@ bool Platform::setUp()
 #ifdef HAVE_LIBGNUTLS
   {
     int r = gnutls_global_init();
-    if(r != GNUTLS_E_SUCCESS) {
-      throw DL_ABORT_EX(fmt("gnutls_global_init() failed, cause:%s",
-                            gnutls_strerror(r)));
+    if (r != GNUTLS_E_SUCCESS) {
+      throw DL_ABORT_EX(
+          fmt("gnutls_global_init() failed, cause:%s", gnutls_strerror(r)));
     }
+
+    gnutls_global_set_log_function(gnutls_log_callback);
+    gnutls_global_set_log_level(0);
   }
 #endif // HAVE_LIBGNUTLS
 
 #ifdef CARES_HAVE_ARES_LIBRARY_INIT
   int aresErrorCode;
-  if((aresErrorCode = ares_library_init(ARES_LIB_INIT_ALL)) != 0) {
-    std::cerr << "ares_library_init() failed:"
-              << ares_strerror(aresErrorCode)
-              << std::endl;
+  if ((aresErrorCode = ares_library_init(ARES_LIB_INIT_ALL)) != 0) {
+    global::cerr()->printf("ares_library_init() failed:%s\n",
+                           ares_strerror(aresErrorCode));
   }
 #endif // CARES_HAVE_ARES_LIBRARY_INIT
 
+#ifdef HAVE_LIBSSH2
+  {
+    auto rv = libssh2_init(0);
+    if (rv != 0) {
+      throw DL_ABORT_EX(fmt("libssh2_init() failed, code: %d", rv));
+    }
+  }
+#endif // HAVE_LIBSSH2
+
 #ifdef HAVE_WINSOCK2_H
   WSADATA wsaData;
   memset(reinterpret_cast<char*>(&wsaData), 0, sizeof(wsaData));
@@ -141,9 +166,11 @@ bool Platform::setUp()
 #endif // HAVE_WINSOCK2_H
 
 #ifdef __MINGW32__
-  unsigned int _CRT_fmode = _O_BINARY;
+  (void)_setmode(_fileno(stdin), _O_BINARY);
+  (void)_setmode(_fileno(stdout), _O_BINARY);
+  (void)_setmode(_fileno(stderr), _O_BINARY);
 #endif // __MINGW32__
-  
+
   return true;
 }
 
@@ -162,16 +189,21 @@ bool Platform::tearDown()
   ares_library_cleanup();
 #endif // CARES_HAVE_ARES_LIBRARY_CLEANUP
 
+#ifdef HAVE_LIBSSH2
+  libssh2_exit();
+#endif // HAVE_LIBSSH2
+
 #ifdef HAVE_WINSOCK2_H
   WSACleanup();
 #endif // HAVE_WINSOCK2_H
-  
+  // Deletes statically allocated resources. This is done to
+  // distinguish memory leak from them. This is handy to use
+  // valgrind.
+  OptionParser::deleteInstance();
+  option::deletePrefResource();
   return true;
 }
 
-bool Platform::isInitialized()
-{
-  return initialized_;
-}
+bool Platform::isInitialized() { return initialized_; }
 
 } // namespace aria2
