@@ -32,64 +32,37 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_RANGE_H_
-#define _D_RANGE_H_
+#ifndef D_RANGE_H
+#define D_RANGE_H
 
 #include "common.h"
-#include "SharedHandle.h"
+
+#include <unistd.h>
 
 namespace aria2 {
 
-class Range {
-private:
-  off_t startByte_;
-  off_t endByte_;
-  uint64_t entityLength_;
-public:
-  Range():startByte_(0), endByte_(0), entityLength_(0) {}
+struct Range {
+  int64_t startByte;
+  int64_t endByte;
+  int64_t entityLength;
 
-  Range(off_t startByte, off_t endByte, uint64_t entityLength):
-    startByte_(startByte), endByte_(endByte), entityLength_(entityLength) {}
+  Range();
 
-  bool operator==(const Range& range) const
-  {
-    return startByte_ == range.startByte_ &&
-      endByte_ == range.endByte_ &&
-      entityLength_ == range.entityLength_;
-  }
+  Range(int64_t startByte, int64_t endByte, int64_t entityLength);
 
-  bool operator!=(const Range& range) const
-  {
-    return !(*this == range);
-  }
+  Range(const Range& c);
 
-  off_t getStartByte() const
-  {
-    return startByte_;
-  }
+  ~Range();
 
-  off_t getEndByte() const
-  {
-    return endByte_;
-  }
+  Range& operator=(const Range& c);
 
-  uint64_t getEntityLength() const
-  {
-    return entityLength_;
-  }
+  bool operator==(const Range& range) const;
 
-  uint64_t getContentLength() const
-  {
-    if(endByte_ >= startByte_) {
-      return endByte_-startByte_+1;
-    } else {
-      return 0;
-    }
-  }
+  bool operator!=(const Range& range) const;
+
+  int64_t getContentLength() const;
 };
 
-typedef SharedHandle<Range> RangeHandle;
-
 } // namespace aria2
 
-#endif // _D_RANGE_H_
+#endif // D_RANGE_H
