@@ -36,7 +36,8 @@
 #define D_REQUEST_GROUP_ENTRY_H
 
 #include "common.h"
-#include "SharedHandle.h"
+
+#include <memory>
 
 namespace aria2 {
 
@@ -46,35 +47,29 @@ class Command;
 class RequestGroupEntry {
 private:
   RequestGroup* requestGroup_;
-  Command* nextCommand_;
+  std::unique_ptr<Command> nextCommand_;
+
 public:
-  RequestGroupEntry(RequestGroup* requestGroup,
-                    Command* nextCommand = 0);
+  RequestGroupEntry(
+      RequestGroup* requestGroup,
+      std::unique_ptr<Command> nextCommand = std::unique_ptr<Command>());
 
   virtual ~RequestGroupEntry();
 
-  RequestGroup* getRequestGroup() const
-  {
-    return requestGroup_;
-  }
+  RequestGroup* getRequestGroup() const { return requestGroup_; }
 
-  Command* getNextCommand() const
-  {
-    return nextCommand_;
-  }
+  const std::unique_ptr<Command>& getNextCommand() const;
 
-  Command* popNextCommand();
+  std::unique_ptr<Command> popNextCommand();
+
+  void pushNextCommand(std::unique_ptr<Command> nextCommand);
 
-  void pushNextCommand(Command* nextCommand);
-  
   bool operator==(const RequestGroupEntry& entry) const
   {
     return this == &entry;
   }
 };
 
-typedef SharedHandle<RequestGroupEntry> RequestGroupEntryHandle;
-
 } // namespace aria2
 
 #endif // D_REQUEST_GROUP_ENTRY_H
