@@ -36,55 +36,39 @@
 #define D_SHARE_RATIO_SEED_CRITERIA_H
 
 #include "SeedCriteria.h"
-#include "DownloadContext.h"
-#include "PeerStorage.h"
-#include "PieceStorage.h"
+
+#include <memory>
 
 namespace aria2 {
 
+class DownloadContext;
+class BtRuntime;
+class PieceStorage;
+
 class ShareRatioSeedCriteria : public SeedCriteria {
 private:
-  double ratio;
-  SharedHandle<DownloadContext> downloadContext_;
-  SharedHandle<PeerStorage> peerStorage_;
-  SharedHandle<PieceStorage> pieceStorage_;
+  double ratio_;
+  std::shared_ptr<DownloadContext> downloadContext_;
+  std::shared_ptr<BtRuntime> btRuntime_;
+  std::shared_ptr<PieceStorage> pieceStorage_;
+
 public:
-  ShareRatioSeedCriteria
-  (double ratio, const SharedHandle<DownloadContext>& downloadContext)
-    :ratio(ratio),
-     downloadContext_(downloadContext) {}
+  ShareRatioSeedCriteria(
+      double ratio, const std::shared_ptr<DownloadContext>& downloadContext);
 
-  virtual ~ShareRatioSeedCriteria() {}
+  virtual ~ShareRatioSeedCriteria();
 
-  virtual void reset() {}
+  virtual void reset() CXX11_OVERRIDE;
 
-  virtual bool evaluate() {
-    if(downloadContext_->getTotalLength() == 0) {
-      return false;
-    }
-    TransferStat stat = peerStorage_->calculateStat();
-    return ratio <=
-      (double)stat.getAllTimeUploadLength()/
-      pieceStorage_->getCompletedLength();
-  }
+  virtual bool evaluate() CXX11_OVERRIDE;
 
-  void setRatio(double ratio) {
-    this->ratio = ratio;
-  }
+  void setRatio(double ratio) { ratio_ = ratio; }
 
-  double getRatio() const {
-    return ratio;
-  }
+  double getRatio() const { return ratio_; }
 
-  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage)
-  {
-    peerStorage_ = peerStorage;
-  }
+  void setBtRuntime(const std::shared_ptr<BtRuntime>& btRuntime);
 
-  void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage)
-  {
-    pieceStorage_ = pieceStorage;
-  }
+  void setPieceStorage(const std::shared_ptr<PieceStorage>& pieceStorage);
 };
 
 } // namespace aria2
