@@ -32,15 +32,45 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_TLS_CONTEXT_H_
-#define _D_TLS_CONTEXT_H_
+#ifndef D_TLS_CONTEXT_H
+#define D_TLS_CONTEXT_H
+
+#include <string>
 
 #include "common.h"
 
-#ifdef HAVE_LIBSSL
-# include "LibsslTLSContext.h"
-#elif HAVE_LIBGNUTLS
-# include "LibgnutlsTLSContext.h"
-#endif // HAVE_LIBGNUTLS
+namespace aria2 {
 
-#endif // _D_TLS_CONTEXT_H_
+enum TLSSessionSide { TLS_CLIENT, TLS_SERVER };
+
+enum TLSVersion {
+  TLS_PROTO_NONE,
+  TLS_PROTO_TLS11,
+  TLS_PROTO_TLS12,
+  TLS_PROTO_TLS13,
+};
+
+class TLSContext {
+public:
+  static TLSContext* make(TLSSessionSide side, TLSVersion minVer);
+  virtual ~TLSContext() = default;
+
+  // private key `keyfile' must be decrypted.
+  virtual bool addCredentialFile(const std::string& certfile,
+                                 const std::string& keyfile) = 0;
+
+  virtual bool addSystemTrustedCACerts() = 0;
+
+  // certfile can contain multiple certificates.
+  virtual bool addTrustedCACertFile(const std::string& certfile) = 0;
+
+  virtual bool good() const = 0;
+
+  virtual TLSSessionSide getSide() const = 0;
+  virtual bool getVerifyPeer() const = 0;
+  virtual void setVerifyPeer(bool) = 0;
+};
+
+} // namespace aria2
+
+#endif // D_TLS_CONTEXT_H
