@@ -32,62 +32,36 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_UNION_SEED_CRITERIA_H_
-#define _D_UNION_SEED_CRITERIA_H_
+#ifndef D_UNION_SEED_CRITERIA_H
+#define D_UNION_SEED_CRITERIA_H
 
 #include "SeedCriteria.h"
-#include <algorithm>
+
 #include <vector>
+#include <memory>
 
 namespace aria2 {
 
 class UnionSeedCriteria : public SeedCriteria {
 private:
-  std::vector<SharedHandle<SeedCriteria> > criterion_;
+  std::vector<std::unique_ptr<SeedCriteria>> criterion_;
 
-  class Reset {
-  public:
-    void operator()(SharedHandle<SeedCriteria> cri)
-    {
-      cri->reset();
-    }
-  };
-
-  class Eval {
-  public:
-    bool operator()(SharedHandle<SeedCriteria> cri)
-    {
-      return cri->evaluate();
-    }
-  };
 public:
-  UnionSeedCriteria() {}
-  virtual ~UnionSeedCriteria() {}
+  UnionSeedCriteria();
+  virtual ~UnionSeedCriteria();
 
-    
-  virtual void reset()
-  {
-    std::for_each(criterion_.begin(), criterion_.end(), Reset());
-  }
+  virtual void reset() CXX11_OVERRIDE;
 
-  virtual bool evaluate()
-  {
-    std::vector<SharedHandle<SeedCriteria> >::iterator itr =
-      std::find_if(criterion_.begin(), criterion_.end(), Eval());
-    return itr != criterion_.end();
-  }
+  virtual bool evaluate() CXX11_OVERRIDE;
 
-  void addSeedCriteria(const SharedHandle<SeedCriteria>& cri)
-  {
-    criterion_.push_back(cri);
-  }
+  void addSeedCriteria(std::unique_ptr<SeedCriteria> cri);
 
-  const std::vector<SharedHandle<SeedCriteria> >& getSeedCriterion() const
+  const std::vector<std::unique_ptr<SeedCriteria>>& getSeedCriterion() const
   {
     return criterion_;
   }
 };
 
 } // namespace aria2
-      
-#endif // _D_UNION_SEED_CRITERIA_H_
+
+#endif // D_UNION_SEED_CRITERIA_H
