@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_MAGNET_H_
-#define _D_MAGNET_H_
+#ifndef D_MAGNET_H
+#define D_MAGNET_H
 
 #include "common.h"
 #include "ValueBase.h"
@@ -42,16 +42,14 @@ namespace aria2 {
 
 namespace magnet {
 
-// Parses Magnet URI magnet and stores parameters in
-// SharedHandle<Dict>.  Because same parameter name can appear more
-// than once, the value associated with a key is SharedHandle<List>. A
-// parameter value is stored in a list. If parsing operation failed,
-// SharedHandle<Dict>() is returned.
-SharedHandle<Dict> parse(const std::string& magnet);
+// Parses Magnet URI magnet and returns the result.  Because same
+// parameter name can appear more than once, the value associated with
+// a key is std::unique_ptr<List>. A parameter value is stored in a
+// list. If parsing operation failed, nullptr is returned.
+std::unique_ptr<Dict> parse(const std::string& magnet);
 
 } // namespace magnet
 
 } // namespace aria2
 
-
-#endif // _D_MAGNET_H_
+#endif // D_MAGNET_H
