@@ -7,33 +7,34 @@
 #include "bittorrent_helper.h"
 #include "Peer.h"
 #include "MockPeerStorage.h"
+#include "SocketBuffer.h"
 
 namespace aria2 {
 
-class BtInterestedMessageTest:public CppUnit::TestFixture {
+class BtInterestedMessageTest : public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(BtInterestedMessageTest);
   CPPUNIT_TEST(testCreate);
   CPPUNIT_TEST(testCreateMessage);
   CPPUNIT_TEST(testDoReceivedAction);
-  CPPUNIT_TEST(testOnSendComplete);
   CPPUNIT_TEST(testToString);
   CPPUNIT_TEST_SUITE_END();
+
 public:
   void testCreate();
   void testCreateMessage();
   void testDoReceivedAction();
-  void testOnSendComplete();
   void testToString();
 };
 
-
 CPPUNIT_TEST_SUITE_REGISTRATION(BtInterestedMessageTest);
 
-void BtInterestedMessageTest::testCreate() {
+void BtInterestedMessageTest::testCreate()
+{
   unsigned char msg[5];
   bittorrent::createPeerMessageString(msg, sizeof(msg), 1, 2);
-  BtInterestedMessageHandle pm = BtInterestedMessage::create(&msg[4], 1);
+  std::shared_ptr<BtInterestedMessage> pm(
+      BtInterestedMessage::create(&msg[4], 1));
   CPPUNIT_ASSERT_EQUAL((uint8_t)2, pm->getId());
 
   // case: payload size is wrong
@@ -42,7 +43,8 @@ void BtInterestedMessageTest::testCreate() {
     bittorrent::createPeerMessageString(msg, sizeof(msg), 2, 2);
     BtInterestedMessage::create(&msg[4], 2);
     CPPUNIT_FAIL("exception must be thrown.");
-  } catch(...) {
+  }
+  catch (...) {
   }
   // case: id is wrong
   try {
@@ -50,50 +52,44 @@ void BtInterestedMessageTest::testCreate() {
     bittorrent::createPeerMessageString(msg, sizeof(msg), 1, 3);
     BtInterestedMessage::create(&msg[4], 1);
     CPPUNIT_FAIL("exception must be thrown.");
-  } catch(...) {
+  }
+  catch (...) {
   }
 }
 
-void BtInterestedMessageTest::testCreateMessage() {
+void BtInterestedMessageTest::testCreateMessage()
+{
   BtInterestedMessage msg;
   unsigned char data[5];
   bittorrent::createPeerMessageString(data, sizeof(data), 1, 2);
-  unsigned char* rawmsg = msg.createMessage();
-  CPPUNIT_ASSERT(memcmp(rawmsg, data, 5) == 0);
-  delete [] rawmsg;
+  auto rawmsg = msg.createMessage();
+  CPPUNIT_ASSERT_EQUAL((size_t)5, rawmsg.size());
+  CPPUNIT_ASSERT(std::equal(std::begin(rawmsg), std::end(rawmsg), data));
 }
 
-void BtInterestedMessageTest::testDoReceivedAction() {
+void BtInterestedMessageTest::testDoReceivedAction()
+{
   BtInterestedMessage msg;
-  SharedHandle<Peer> peer(new Peer("host", 6969));
-  peer->allocateSessionResource(1024, 1024*1024);
+  std::shared_ptr<Peer> peer(new Peer("host", 6969));
+  peer->allocateSessionResource(1_k, 1_m);
   msg.setPeer(peer);
 
-  SharedHandle<MockPeerStorage> peerStorage(new MockPeerStorage());
+  auto peerStorage = make_unique<MockPeerStorage>();
 
-  msg.setPeerStorage(peerStorage);
+  msg.setPeerStorage(peerStorage.get());
 
   CPPUNIT_ASSERT(!peer->peerInterested());
   msg.doReceivedAction();
   CPPUNIT_ASSERT(peer->peerInterested());
-  CPPUNIT_ASSERT_EQUAL(0, peerStorage->getNumChokeExecuted());
+  CPPUNIT_ASSERT_EQUAL(1, peerStorage->getNumChokeExecuted());
 
   peer->amChoking(false);
   msg.doReceivedAction();
   CPPUNIT_ASSERT_EQUAL(1, peerStorage->getNumChokeExecuted());
 }
 
-void BtInterestedMessageTest::testOnSendComplete() {
-  BtInterestedMessage msg;
-  SharedHandle<Peer> peer(new Peer("host", 6969));
-  peer->allocateSessionResource(1024, 1024*1024);
-  msg.setPeer(peer);
-  CPPUNIT_ASSERT(!peer->amInterested());
-  msg.onSendComplete();
-  CPPUNIT_ASSERT(peer->amInterested());
-}
-
-void BtInterestedMessageTest::testToString() {
+void BtInterestedMessageTest::testToString()
+{
   BtInterestedMessage msg;
   CPPUNIT_ASSERT_EQUAL(std::string("interested"), msg.toString());
 }
