@@ -1,20 +1,23 @@
 #include "GZipDecoder.h"
-#include "Exception.h"
-#include "util.h"
-#ifdef ENABLE_MESSAGE_DIGEST
-# include "MessageDigestHelper.h"
-#endif // ENABLE_MESSAGE_DIGEST
+
 #include <iostream>
 #include <fstream>
+
 #include <cppunit/extensions/HelperMacros.h>
 
+#include "TestUtil.h"
+#include "Exception.h"
+#include "util.h"
+#include "MessageDigest.h"
+
 namespace aria2 {
 
-class GZipDecoderTest:public CppUnit::TestFixture {
+class GZipDecoderTest : public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(GZipDecoderTest);
   CPPUNIT_TEST(testDecode);
   CPPUNIT_TEST_SUITE_END();
+
 public:
   void setUp() {}
 
@@ -23,7 +26,6 @@ public:
   void testDecode();
 };
 
-
 CPPUNIT_TEST_SUITE_REGISTRATION(GZipDecoderTest);
 
 void GZipDecoderTest::testDecode()
@@ -31,16 +33,16 @@ void GZipDecoderTest::testDecode()
   GZipDecoder decoder;
   decoder.init();
 
-  std::string outfile("./aria2_GZipDecoderTest_testDecode");
+  std::string outfile(A2_TEST_OUT_DIR "/aria2_GZipDecoderTest_testDecode");
 
-  char buf[4096];
-  std::ifstream in("gzip_decode_test.gz", std::ios::binary);
+  char buf[4_k];
+  std::ifstream in(A2_TEST_DIR "/gzip_decode_test.gz", std::ios::binary);
   std::ofstream out(outfile.c_str(), std::ios::binary);
-  while(in) {
+  while (in) {
     in.read(buf, sizeof(buf));
 
-    std::string r = decoder.decode
-      (reinterpret_cast<const unsigned char*>(buf), in.gcount());
+    std::string r = decoder.decode(reinterpret_cast<const unsigned char*>(buf),
+                                   in.gcount());
 
     out.write(r.data(), r.size());
   }
@@ -49,11 +51,8 @@ void GZipDecoderTest::testDecode()
 
   out.close();
 
-#ifdef ENABLE_MESSAGE_DIGEST
   CPPUNIT_ASSERT_EQUAL(std::string("8b577b33c0411b2be9d4fa74c7402d54a8d21f96"),
-                       MessageDigestHelper::digest(MessageDigestContext::SHA1,
-                                                   outfile));
-#endif // ENABLE_MESSAGE_DIGEST
+                       fileHexDigest(MessageDigest::sha1().get(), outfile));
 }
 
 } // namespace aria2
